@@ -18,6 +18,9 @@
  */
 
 #include "setconfigoperation.h"
+
+#include "abstractbackend.h"
+#include "backendmanager_p.h"
 #include "configoperation_p.h"
 #include "config.h"
 #include "configserializer_p.h"
@@ -99,7 +102,6 @@ void SetConfigOperationPrivate::onConfigSet(QDBusPendingCallWatcher *watcher)
     q->emitResult();
 }
 
-
 SetConfigOperation::SetConfigOperation(const ConfigPtr &config, QObject* parent)
     : ConfigOperation(new SetConfigOperationPrivate(config, this), parent)
 {
@@ -115,11 +117,16 @@ ConfigPtr SetConfigOperation::config() const
     return d->config;
 }
 
-
 void SetConfigOperation::start()
 {
     Q_D(SetConfigOperation);
-    d->requestBackend();
+    if (BackendManager::instance()->method() == BackendManager::InProcess) {
+        auto backend = d->loadBackend();
+        backend->setConfig(d->config);
+        emitResult();
+    } else {
+        d->requestBackend();
+    }
 }
 
 #include "setconfigoperation.moc"
